/* ****************************************************************************************************************************

--------------------------------------------------------
MA_Skyfakes_Examples
--------------------------------------------------------
Author:			Martin Seydler
Website:		www.maetes.com
Documentation:	https://www.maetes.com/en/povray-os/ma_skyfakes
Date:			November 2018 an later
Version:		1.0 (December 2024)
Copyright:		See above (author), below near any macro (orignal author and sources) and everywhere (www.povray.org)
License:		Use it in your projects as you like. A mention and a link to my website would be nice.


Helpful Command-Lines (change the path):
------------------------------------------
povray +Ima_skyfakes_examples.pov +Otest/ma_skyfakes.png +w800 +h500 -GR +A
povray +Ima_skyfakes_examples.pov +Otest/ma_skyfakes.png +w1200 +h675 +GD +GF -GR +GS +GW +Q9 +A
povray +Ima_skyfakes_examples.pov +Otest/ma_skyfakes.png +w1920 +h1080 +GD +GF -GR +GS +GW +Q9 +A

povray +Ima_skyfakes_examples.pov +Otest/ma_skyfakes.png +w2000 +h1500 +GD +GF -GR +GS +GW +Q9 +A

To open the resulting picture in a Browser (change the path):
-----------------------------------------------------------------
file:///home/pi/Projekte/povray/packages-ma/astro/ma_skyfakes/test/


*/// **************************************************************************************************************************


#version 3.7;


//Set some defaults
global_settings		{ assumed_gamma 1.0 }
#default {
	finish { ambient 0.005 diffuse 0.99 }	//Org
}



//-----------------------------------------------------------------------------------------------------
//Try to include ma_helpers. My dev-folder has highest priority.
//-----------------------------------------------------------------------------------------------------
#local mH = array[2] {"../../misc/ma_helpers/ma_helpers.inc", "ma_helpers.inc" }
#for (mI, 0, dimension_size(mH,1) - 1) #if (file_exists(mH[mI])) #include mH[mI] #end #end #ifndef (MA_Helpers_Temp) #error "Cant find 'ma_helpers.inc'"; #end


//Include Skyfakes
#include "ma_skyfakes.inc"
#include "ma_skyfakes_textures.inc"


#declare LigVector		= <20,2,-20>*1000;
#declare CamLocation	= <0,2,-25>;
#declare CamAngle		= 80;


MA_SetClock(0.5)				//For sill-images, without running clock


//-----------------------------------------------------------------------------------------------------
//Needed from some examples to show one big planet at the left and four smaller on the right.
//-----------------------------------------------------------------------------------------------------
#macro ShowPlanet(mPlanet)
	object {
			mPlanet			scale 5			rotate <-5,0,+5>			translate <-3,0,0>
	}
	#for (mNumber, 0, 3)
		object {
			mPlanet			scale 1			rotate <0,mNumber * 90,0>	translate <+6,+4 - mNumber*3,0>
		}
	#end
#end

//-----------------------------------------------------------------------------------------------------
//Choose one example. The star-background will be generated all the time, so it doesnt look too boring
//Only the last "x" gets generated (easier to switch from one to the other)
//-----------------------------------------------------------------------------------------------------

#local Example	= "stars";
#local Example	= "sun-and-stars";

#local xExample	= "gasgiant-1";
#local xExample	= "moon-1";
#local xExample	= "minshara-1";

#local xExample	= "most-planets-1";
#local xExample	= "planet-specials-1";
#local Example	= "atmo-problems-1";

#local Example	= "horizon-1";
#local Example	= "horizon-2";
#local Example	= "perspective";

#local Example	= "tussi";



	
//-----------------------------------------------------------------------------------------------------------------------
//-----------------------------------------------------------------------------------------------------------------------
#if (xExample = "stars")
	sky_sphere {
		SF_BackgroundStars_Pigment(2,5)
	}
	
//-----------------------------------------------------------------------------------------------------------------------
//-----------------------------------------------------------------------------------------------------------------------
#elseif (xExample = "sun-and-stars")
	sky_sphere {
		SF_BackgroundStars_Pigment(2,5)

		//Rotate the sun, 0/0 will show it at Z+
		//To place the visible sun and the invisible Light-Vector at the same location return the light also.
		//#declare LigRotate = <SunRotateX, ????
		#local SunRotateX = -10; //down (+) or up (-). Seems unlogically, but its the normal rotation of the X-Vector.
		#local SunRotateY = +10; //right (+) or left (-).
		
		SF_BackgroundSun_Pigment(1, 1, SunRotateX, SunRotateY)
		
	}






//-----------------------------------------------------------------------------------------------------------------------
//-----------------------------------------------------------------------------------------------------------------------
#elseif (xExample = "gasgiant-1")	//
	sky_sphere { SF_BackgroundStars_Pigment(2,5) }
	
	#local mPlanet = SF_Gasgiant1("","","")
	ShowPlanet(mPlanet)
	
//-----------------------------------------------------------------------------------------------------------------------
//-----------------------------------------------------------------------------------------------------------------------
#elseif (xExample = "moon-1")	//
	sky_sphere { SF_BackgroundStars_Pigment(2,5) }
	
	#local mPlanet = SF_Moon1("","","")
	ShowPlanet(mPlanet)
	
//-----------------------------------------------------------------------------------------------------------------------
//-----------------------------------------------------------------------------------------------------------------------
#elseif (xExample = "minshara-1")	//
	sky_sphere { SF_BackgroundStars_Pigment(2,5) }
	
	#local mPlanet = SF_Minshara1("","","")
	ShowPlanet(mPlanet)
	
//-----------------------------------------------------------------------------------------------------------------------
//-----------------------------------------------------------------------------------------------------------------------
#elseif (xExample = "most-planets-1")

	sky_sphere { SF_BackgroundStars_Pigment(3,2) }

	#declare CamAngle		= 40;
	#local mScale			= 1.8;
	object {
		SF_Minshara1("","","")
		scale mScale
		translate <-5,0,0>
	}
	object {
		SF_Gasgiant1("","","")
		scale mScale
		translate <-0,0,0>
	}
	object {
		SF_Moon1("","","")
		scale mScale
		translate <+5,0,0>
	}

//-----------------------------------------------------------------------------------------------------------------------
//-----------------------------------------------------------------------------------------------------------------------
#elseif (xExample = "planet-specials-1")

	sky_sphere { SF_BackgroundStars_Pigment(3,2) }

	#declare LigVector		= <20,2,-10>*1000;
	#declare CamAngle		= 43;

	#local mScale	= 1.5;
	object {
		SF_Gasgiant1("","","atmo-type: simple-1;atmo-scattering-color: <0.9, 0.2, 0.2>")
		scale mScale
		translate <-5, +2.5, 0>
	}
	object {
		SF_Moon1("","","atmo-type: simple-1")
		scale mScale
		translate <-0, +2.5, 0>
	}
	object {
		SF_Minshara1("","","atmo-type: simple-1")
		scale mScale
		translate <+5, +2.5, 0>
	}
	object {
		SF_Minshara1("","","atmo-type: simple-1;rings-type: saturn-1")
		scale mScale
		translate <-0, -2.5, 0>
	}

//-----------------------------------------------------------------------------------------------------------------------
//-----------------------------------------------------------------------------------------------------------------------
#elseif (xExample = "atmo-problems-1")

	sky_sphere { SF_BackgroundStars_Pigment(2,3) }

	#declare LigVector		= <20,2,-10>*10000000;
	#declare CamAngle		= 30;
	#declare CamLocation	= <0,0,-20>;

	object {
		SF_Minshara1("","","atmo-type: simple-1; atmo-scattering-factor: 0.0120")		//Big size, big distance, low sc-factor
		scale 2500
		translate <-8000, 0, 50000>
	}
	object {
		SF_Minshara1("","","atmo-type: simple-1; atmo-scattering-factor: 40")			//Small size, small distance, high sc-factor
		scale 1
		translate < 0, 0, 0>
	}
	object {
		SF_Minshara1("","","atmo-type: simple-1; atmo-scattering-factor: 40")			//Big size, big distance, low sc-factor, much to light
		scale 2500
		translate <+8000, 0, 50000>
	}
	


	
	
	
	
	
	
//-----------------------------------------------------------------------------------------------------------------------
//-----------------------------------------------------------------------------------------------------------------------
#elseif (xExample = "horizon-1")	//
	sky_sphere {
		SF_BackgroundStars_Pigment(2,5)
		SF_BackgroundSun_Pigment(1, 1, 0, +15)
		//rotate <SunRotateX,SunRotateY,0>
	}
	object {
		SF_Gasgiant1("", "", "rings-type: saturn-1") 
		scale 3
		rotate <-15,0,+5>
		translate <-10,30,200>
	}
	object {
		SF_Horizon1 ( "", "", "", "l", <0,10,0>) 						//position, rotation
		//rotate <x,y,z> //DONT USE THIS, because the horizon is off-axis by thousands of pu! Use the macro-parameter instead.
	}

	
//-----------------------------------------------------------------------------------------------------------------------
//-----------------------------------------------------------------------------------------------------------------------
#elseif (xExample = "horizon-2")	//
	sky_sphere {
		SF_BackgroundStars_Pigment(2,2)
		SF_BackgroundSun_Pigment(1, 1, 0, +15)
		//rotate <SunRotateX,SunRotateY,0>
	}
	
	
	#local FileUC = "ma_skyfakes_uc.inc";
	#if (file_exists(FileUC))
		#include FileUC
		
		object {
			SF_Horizon2 ( "", "", "", "l", 1) 						//position, rotation
		}
	#end

	#declare LigVector		= <20,2,20>*10000;	
	#declare CamLookAt		= <0,2,0>;
	
	
//-----------------------------------------------------------------------------------------------------------------------
// FOR INTERNAL USE ONLY
//-----------------------------------------------------------------------------------------------------------------------
#elseif (xExample = "perspective")	//

	#declare CamAngle		= 90;
	#declare CamLocation	= <0,0,-20>;
	#declare CamType		= "perspective";
	//#declare CamType		= "ultra_wide_angle";

	sky_sphere {
		SF_BackgroundStars_Pigment(2,5)
		SF_BackgroundSun_Pigment(1, 1, -20, +35)
		SF_BackgroundSun_Pigment(1, 1, -20, -35)
		//rotate <SunRotateX,SunRotateY,0>
	}
	object {
		SF_Gasgiant1("", "", "") 
		scale 4
		translate <0,1,5>
	}
	object {
		SF_Horizon1 ("","","", "b", <0,0,0>) //Position, Rotation
		//rotate <x,y,z> //DONT USE THIS, because the horizon is off-axis by 1000000 pu! Use the makro-parameter instead
	}
	

	
//-----------------------------------------------------------------------------------------------------------------------
// FOR INTERNAL USE ONLY
// Needs Tussi within reach.
//-----------------------------------------------------------------------------------------------------------------------
#elseif (xExample = "tussi")

	#declare CamAngle		= 90;
	#declare CamLocation	= <0,0,-60>;
	#declare CamType		= "perspective";
	//#declare CamType		= "ultra_wide_angle";
	#declare LigVector		= <5,6,-2>*10000;

	sky_sphere { SF_BackgroundStars_Pigment(2,5) }
	
	object {
		union {
			object {
				SF_Gasgiant1("", "", "rings-type: saturn-1")
				scale 2
				rotate <-15,-45,+15>
			}
			object {
				SF_Minshara1("", "", "atmo-type: simple-1; atmo-scattering-factor: 0.440")
				scale 0.6
				translate <10,0,00>
			}
		}
		scale 60
		translate <50,1000,3000> 
	}
	
	object {
		SF_Horizon1 ("","","", "l", <180,15,0>) //Position, Rotation
	}
	
	#local TussiFile = "../../space/ma_tussi/ma_tussi.inc";
	#if (file_exists(TussiFile))
		#include TussiFile
		#local Params = "sc-angle:90;sc-tilt:30"
		
		#local Tussi = TU_Tussi ("", "", Params, "");
		object {
			Tussi
			scale 2
			rotate <45,0,0>
			translate <-4,-4,0>
		}
		
	#end

//-----------------------------------------------------------------------------------------------------------------------
//-----------------------------------------------------------------------------------------------------------------------
#else
	//Warning, no existing example choosen
	//DoNothingLoop()
	
#end


MA_CameraAndLight_Set()



		


